MetricDescriptor_MetricKind class

The kind of measurement. It describes how the data is reported. For information on setting the start time and end time based on the MetricKind, see google.monitoring.v3.TimeInterval.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
This enum's name, as specified in the .proto file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
This enum's integer value, as specified in the .proto file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns this enum's name or the value if names are not represented.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueOf(int value) MetricDescriptor_MetricKind?

Constants

CUMULATIVE → const MetricDescriptor_MetricKind
A value accumulated over a time interval. Cumulative measurements in a time series should have the same start time and increasing end times, until an event resets the cumulative value to zero and sets a new start time for the following points.
DELTA → const MetricDescriptor_MetricKind
The change in a value during a time interval.
GAUGE → const MetricDescriptor_MetricKind
An instantaneous measurement of a value.
METRIC_KIND_UNSPECIFIED → const MetricDescriptor_MetricKind
Do not use this default value.
values → const List<MetricDescriptor_MetricKind>