fieldName property

  1. @TagNumber.new(5)
String get fieldName

The name of the field for which this lint result is about.

For nested messages field_name consists of names of the embedded fields separated by period character. The top-level qualifier is the input object to lint in the request. For example, the field_name value condition.expression identifies a lint result for the expression field of the provided condition.

Implementation

@$pb.TagNumber(5)
$core.String get fieldName => $_getSZ(3);
  1. @TagNumber.new(5)
set fieldName (String value)

Implementation

@$pb.TagNumber(5)
set fieldName($core.String value) => $_setString(3, value);