includedPermissions property
The names of the permissions this role grants when bound in an IAM policy.
Implementation
@$pb.TagNumber(7)
$pb.PbList<$core.String> get includedPermissions => $_getList(3);
The names of the permissions this role grants when bound in an IAM policy.
@$pb.TagNumber(7)
$pb.PbList<$core.String> get includedPermissions => $_getList(3);