getIamPolicy method
Gets the IAM policy that is attached to a google.iam.admin.v1.ServiceAccount. This IAM
policy specifies which principals have access to the service account.
This method does not tell you whether the service account has been granted
any roles on other resources. To check whether a service account has role
grants on a resource, use the getIamPolicy method for that resource. For
example, to view the role grants for a project, call the Resource Manager
API's
projects.getIamPolicy
method.
Implementation
$grpc.ResponseFuture<$3.Policy> getIamPolicy(
$2.GetIamPolicyRequest request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$getIamPolicy, request, options: options);
}