lintPolicy method

ResponseFuture<LintPolicyResponse> lintPolicy(
  1. LintPolicyRequest request, {
  2. CallOptions? options,
})

Lints, or validates, an IAM policy. Currently checks the google.iam.v1.Binding.condition field, which contains a condition expression for a role binding.

Successful calls to this method always return an HTTP 200 OK status code, even if the linter detects an issue in the IAM policy.

Implementation

$grpc.ResponseFuture<$0.LintPolicyResponse> lintPolicy(
  $0.LintPolicyRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$lintPolicy, request, options: options);
}