undeleteServiceAccount method

ResponseFuture<UndeleteServiceAccountResponse> undeleteServiceAccount(
  1. UndeleteServiceAccountRequest request, {
  2. CallOptions? options,
})

Restores a deleted google.iam.admin.v1.ServiceAccount.

Important: It is not always possible to restore a deleted service account. Use this method only as a last resort.

After you delete a service account, IAM permanently removes the service account 30 days later. There is no way to restore a deleted service account that has been permanently removed.

Implementation

$grpc.ResponseFuture<$0.UndeleteServiceAccountResponse>
    undeleteServiceAccount(
  $0.UndeleteServiceAccountRequest request, {
  $grpc.CallOptions? options,
}) {
  return $createUnaryCall(_$undeleteServiceAccount, request,
      options: options);
}