IAMPolicyServiceBase class abstract

Annotations
  • @GrpcServiceName.new('google.iam.v1.IAMPolicy')

Constructors

IAMPolicyServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getIamPolicy(ServiceCall call, GetIamPolicyRequest request) Future<Policy>
getIamPolicy_Pre(ServiceCall $call, Future<GetIamPolicyRequest> $request) Future<Policy>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(ServiceCall call, SetIamPolicyRequest request) Future<Policy>
setIamPolicy_Pre(ServiceCall $call, Future<SetIamPolicyRequest> $request) Future<Policy>
testIamPermissions(ServiceCall call, TestIamPermissionsRequest request) Future<TestIamPermissionsResponse>
testIamPermissions_Pre(ServiceCall $call, Future<TestIamPermissionsRequest> $request) Future<TestIamPermissionsResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited