bindings property

  1. @TagNumber.new(4)
PbList<Binding> get bindings

Associates a list of members, or principals, with a role. Optionally, may specify a condition that determines how and when the bindings are applied. Each of the bindings must contain at least one principal.

The bindings in a Policy can refer to up to 1,500 principals; up to 250 of these principals can be Google groups. Each occurrence of a principal counts towards these limits. For example, if the bindings grant 50 different roles to user:alice@example.com, and not to any other principal, then you can add another 1,450 principals to the bindings in the Policy.

Implementation

@$pb.TagNumber(4)
$pb.PbList<Binding> get bindings => $_getList(2);